@@ -1,3 +1,4 @@
+import sys
 import logging
 import subprocess
 
@@ -5,6 +6,7 @@ from typing import Optional, Callable, List, Tuple, Set, Dict, cast
 from os import environ, name as osname
 from signal import SIGTERM
 from socket import error as SocketError
+from datetime import datetime
 
 import gevent
 
@@ -192,6 +194,32 @@ def setup_environment_listeners(context: Context, environment: Environment, requ
     return external_dependencies
 
 
+def print_scenario_summary(grizzly: GrizzlyContext) -> None:
+    def print_table_lines(length: int) -> None:
+        length -= 11
+        sys.stdout.write('-' * 10)
+        sys.stdout.write('|')
+        sys.stdout.write('-' * length)
+        sys.stdout.write('|\n')
+
+    rows: List[str] = []
+    max_length = 0
+
+    for scenario in grizzly.scenarios():
+        row = '{:11} {}'.format(scenario.identifier, scenario.description or 'unknown')
+        row_length = len(row)
+        if row_length > max_length:
+            max_length = row_length
+        rows.append(row)
+
+    print('Scenario')
+    print('{:11} {}'.format('identifier', 'description'))
+    print_table_lines(max_length)
+    for row in rows:
+        print(row)
+    print_table_lines(max_length)
+
+
 def run(context: Context) -> int:
     grizzly = cast(GrizzlyContext, context.grizzly)
 
@@ -390,7 +418,14 @@ def run(context: Context) -> int:
                 print_stats(runner.stats, current=False)
                 print_percentile_stats(runner.stats)
                 print_error_report(runner.stats)
+                print_scenario_summary(grizzly)
 
+                # show start and stop date time
+                stopped = datetime.now()
+
+                print('')
+                print(f'Started: {context.started}')
+                print(f'Stopped: {stopped}')
 
             return code
 
