@@ -1,5 +1,5 @@
 '''This module contains step implementations that describes the actual load all scenarios in a feature will generate.'''
-from typing import cast
+from typing import Any, Dict, cast
 
 import parse
 
@@ -7,6 +7,7 @@ from behave.runner import Context
 from behave import register_type, given  # pylint: disable=no-name-in-module
 
 from ...context import GrizzlyContext
+from ...testdata.utils import resolve_variable
 
 
 @parse.with_pattern(r'(user[s]?)')
@@ -19,8 +20,8 @@ register_type(
 )
 
 
-@given(u'"{user_count:d}" {user_number:UserGramaticalNumber}')
-def step_shapes_user_count(context: Context, user_count: int, user_number: str) -> None:
+@given(u'"{value}" {grammar:UserGramaticalNumber}')
+def step_shapes_user_count(context: Context, value: str, **kwargs: Dict[str, Any]) -> None:
     '''Set number of users that will generate load.
 
     ```gherkin
@@ -32,21 +33,23 @@ def step_shapes_user_count(context: Context, user_count: int, user_number: str)
     Args:
         user_count (int): Number of users locust should create
     '''
-    if user_count > 1:
-        assert user_number == 'users', 'when user_count is greater than 1, use "users"'
-    else:
-        assert user_number == 'user', 'when user_count is 1, use "user"'
-
     grizzly = cast(GrizzlyContext, context.grizzly)
+    should_resolve = '{{' in value and '}}' in value or value[0] == '$'
+    user_count = int(round(float(resolve_variable(grizzly, value)), 0))
+
+    if should_resolve and user_count < 1:
+        user_count = 1
+
+    assert user_count >= 0, f'{value} resolved to {user_count} users, which is not valid'
 
     if grizzly.setup.spawn_rate is not None:
-        assert user_count > grizzly.setup.spawn_rate, f'spawn rate can not be greater than user count'
+        assert user_count >= grizzly.setup.spawn_rate, f'spawn rate ({grizzly.setup.spawn_rate}) can not be greater than user count ({user_count})'
 
     grizzly.setup.user_count = user_count
 
 
-@given(u'spawn rate is "{spawn_rate:g}" {user_number:UserGramaticalNumber} per second')
-def step_shapes_spawn_rate(context: Context, spawn_rate: float, user_number: str) -> None:
+@given(u'spawn rate is "{value}" {grammar:UserGramaticalNumber} per second')
+def step_shapes_spawn_rate(context: Context, value: str, **kwargs: Dict[str, Any]) -> None:
     '''Set rate in which locust shall swarm new user instances.
 
     ```gherkin
@@ -58,7 +61,15 @@ def step_shapes_spawn_rate(context: Context, spawn_rate: float, user_number: str
     Args:
         spawn_rate (float): number of users per second
     '''
+    assert isinstance(value, str), f'{value} is not a string'
     grizzly = cast(GrizzlyContext, context.grizzly)
+    should_resolve = '{{' in value and '}}' in value or value[0] == '$'
+    spawn_rate = float(resolve_variable(grizzly, value))
+
+    if should_resolve and spawn_rate < 0.01:
+        spawn_rate = 0.01
+
+    assert spawn_rate > 0.0, f'{value} resolved to {spawn_rate} users, which is not valid'
 
     if grizzly.setup.user_count is not None:
         assert int(spawn_rate) <= grizzly.setup.user_count, f'spawn rate can not be greater than user count'
