@@ -1,13 +1,17 @@
 '''This module contains step implementations that describes requests sent by `user_class_name` targeting `host`.'''
 from typing import cast
+from urllib.parse import urlparse
 
 from behave.runner import Context
 from behave import register_type, then  # pylint: disable=no-name-in-module
 
 from ..helpers import add_request_task
-from ...types import RequestDirection, RequestMethod, ResponseContentType, str_response_content_type
+from ...types import RequestDirection, RequestMethod
 from ...context import GrizzlyContext
-from ...task import PrintTask, SleepTask, TransformerTask
+from ...task import PrintTask, WaitTask, TransformerTask
+from ...task.getter import getterof
+
+from grizzly_extras.transformer import TransformerContentType
 
 
 def parse_method(text: str) -> RequestMethod:
@@ -21,7 +25,7 @@ def parse_direction(text: str) -> RequestDirection:
 register_type(
     Direction=parse_direction,
     Method=parse_method,
-    ContentType=str_response_content_type,
+    ContentType=TransformerContentType.from_string,
 )
 
 
@@ -47,15 +51,27 @@ def step_task_request_text_with_name_to_endpoint(context: Context, method: Reque
         """
     Then get request with name "test-get" from endpoint "/api/test"
 
-    Then send request with name "test-send" to endpoint "receive-queue"
+    Then send request with name "test-send" to endpoint "queue:receive-queue"
         """
         {
             "value": "do something"
         }
         """
-    Then receive request with name "test-receive" from endpoint "receive-queue"
+    Then receive request with name "test-receive" from endpoint "queue:receive-queue"
     ```
 
+    `endpoint` has support for setting response content type as a parameter:
+
+    ```gherkin
+    Then receive request with name "test-receive" from endpoint "queue:receive-queue | content_type=xml"
+
+    # same as
+    Then receive request with name "test-receive" from endpoint "queue:receive-queue"
+    And set response content type to "xml"
+    ```
+
+    `content_type` will be removed from the actual `endpoint` value.
+
     Args:
         method (RequestMethod): type of request
         name (str): name of the requests in logs, can contain variables
@@ -80,11 +96,23 @@ def step_task_request_file_with_name_endpoint(context: Context, method: RequestM
     '''Creates a named request to an endpoint on `host`, where the payload is defined in a template file.
 
     ```gherkin
-    Then send request "test/request.j2.json" with name "test-send" to endpoint "receive-queue"
+    Then send request "test/request.j2.json" with name "test-send" to endpoint "queue:receive-queue"
     Then post request "test/request.j2.json" with name "test-post" to endpoint "/api/test"
     Then put request "test/request.j2.json" with name "test-put" to endpoint "/api/test"
     ```
 
+    `endpoint` has support for setting response content type as a parameter:
+
+    ```gherkin
+    Then put request "test/request.j2.json" with name "test-put" to endpoint "/api/test | content_type=json"
+
+    # same as
+    Then put request "test/request.j2.json" with name "test-put" to endpoint "/api/test"
+    And set response content type to "application/json"
+    ```
+
+    `content_type` will be removed from the actual `endpoint` value.
+
     Args:
         method (RequestMethod): type of request
         source (str): path to a template file relative to the directory `requests/`, which **must** exist in the directory the feature file is located
@@ -109,6 +137,18 @@ def step_task_request_file_with_name(context: Context, method: RequestMethod, so
     Then post request "test/request2.j2.json" with name "test-post2" to endpoint "/api/test"
     ```
 
+    `endpoint` has support for setting response content type as a parameter:
+
+    ```gherkin
+    Then post request "test/request1.j2.json" with name "test-post1" to endpoint "/api/test | content_type=json"
+
+    # same as
+    Then post request "test/request1.j2.json" with name "test-post1" to endpoint "/api/test"
+    And set response content type to "application/json"
+    ```
+
+    `content_type` will be removed from the actual `endpoint` value.
+
     Args:
         method (RequestMethod): type of request
         source (str): path to a template file relative to the directory `requests/`, which **must** exist in the directory the feature file is located
@@ -196,7 +236,7 @@ def step_task_wait_seconds(context: Context, wait_time: float) -> None:
 
     assert wait_time > 0.0, f'wait time cannot be less than 0.0 seconds'
 
-    grizzly.scenario.add_task(SleepTask(sleep=wait_time))
+    grizzly.scenario.add_task(WaitTask(time=wait_time))
 
 
 @then(u'print message "{message}"')
@@ -215,9 +255,12 @@ def step_task_print_message(context: Context, message: str) -> None:
     grizzly = cast(GrizzlyContext, context.grizzly)
     grizzly.scenario.add_task(PrintTask(message=message))
 
+    if '{{' in message and '}}' in message:
+        grizzly.scenario.orphan_templates.append(message)
+
 
 @then(u'parse "{content}" as "{content_type:ContentType}" and save value of "{expression}" in variable "{variable}"')
-def step_task_transform(context: Context, content: str, content_type: ResponseContentType, expression: str, variable: str) -> None:
+def step_task_transform(context: Context, content: str, content_type: TransformerContentType, expression: str, variable: str) -> None:
     '''Parse (part of) a JSON object or a XML document and extract a specific value from that and save into a variable.
 
     This can be especially useful in combination with [`AtomicMessageQueue`](/grizzly/usage/variables/testdata/messagequeue/) variable.
@@ -233,7 +276,7 @@ def step_task_transform(context: Context, content: str, content_type: ResponseCo
 
     Args:
         contents (str): contents to parse, supports templating or a static string
-        content_type (ResponseContentType): MIME type of `contents`
+        content_type (TransformerContentType): MIME type of `contents`
         expression (str): JSON or XPath expression for specific value in `contents`
         variable (str): name of variable to save value to, must have been initialized
     '''
@@ -248,3 +291,42 @@ def step_task_transform(context: Context, content: str, content_type: ResponseCo
 
     if '{{' in content and '}}' in content:
         grizzly.scenario.orphan_templates.append(content)
+
+
+@then(u'get "{endpoint}" and save response in "{variable}"')
+def step_task_get_endpoint(context: Context, endpoint: str, variable: str) -> None:
+    '''Get information from another host or endpoint than the scenario is load testing and save the response in a variable.
+
+    Task implementations are found in `grizzly.task.getter` and each implementation is looked up through the scheme in the
+    specified endpoint. If the endpoint is a variable, one have to manually specify the endpoint scheme even though the
+    resolved variable contains the scheme. In this case the manually specified scheme will be removed to the endpoint actually
+    used by the task.
+
+    ```gherkin
+    Then get "https://www.example.org/example.json" and save response in "example_openapi"
+    Then get "http://{{ endpoint }}" and save response in "endpoint_result"
+    ```
+
+    Args:
+        endpoint (str): information about where to get information, see the specific getter task implementations for more information
+        variable (str): name of, initialized, variable where response will be saved in
+    '''
+    grizzly = cast(GrizzlyContext, context.grizzly)
+
+    scheme = urlparse(endpoint).scheme
+
+    assert scheme is not None and len(scheme) > 0, f'could not find scheme in "{endpoint}"'
+
+    getter = getterof.available.get(scheme, None)
+
+    assert getter is not None, f'no getter task registered for {scheme}'
+
+    if '{{' in endpoint and '}}' in endpoint:
+        grizzly.scenario.orphan_templates.append(endpoint)
+        index = len(scheme) + 3
+        endpoint = endpoint[index:]
+
+    grizzly.scenario.add_task(getter(
+        endpoint=endpoint,
+        variable=variable,
+    ))
